@@ -1,12 +1,14 @@
 /// File type of the image
 #[derive(Debug, Eq, PartialEq, Copy, Clone)]
-#[cfg_attr(feature = "avif", non_exhaustive)]
+#[cfg_attr(any(feature = "avif", feature = "webp"), non_exhaustive)]
 pub enum Format {
     Unknown,
     Jpeg,
     Png,
     #[cfg(feature = "avif")]
     Avif,
+    #[cfg(feature = "webp")]
+    WebP,
 }
 
 impl Default for Format {
